<?php
namespace bwdsypx_ShowcaseProfile_namespace;

use bwdsypx_ShowcaseProfile_namespace\PageSettings\Page_Settings;
define( "BWDSYPX_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDSYPX_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class Classbwdsypx_ShowcaseProfile {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdsypx_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdsypx_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdsypx_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdsypx_ShowcaseProfile_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdsypx-showcase-profile-widgets.php' );
	}

	public function bwdsypx_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdsypx_ShowcaseProfile_widgets());
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdsypx-showcase-profile-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdsypx_ShowcaseProfile_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdsypx-ShowcaseProfile-category',
			[
				'title' => esc_html__( 'Showcase Your Profile', 'bwdsypx-profile-showcasing' ),
				'icon' => 'eicon-person',
			]
		);
	}

	//css-js-link-here
	public function bwdsypx_all_assets_for_the_public(){

		wp_enqueue_script( 'bwdsypx-ShowcaseProfile-swiper-main', plugin_dir_url( __FILE__ ) . 'assets/public/js/swiper-bundle.min.js', array('jquery'), '1.3', true );
		wp_enqueue_script( 'bwdsypx-ShowcaseProfile-main', plugin_dir_url( __FILE__ ) . 'assets/public/js/main.js', array('jquery'), '1.3', true );

		$all_css_file = array(
			'bwdsypx-ShowcaseProfile-plugin-swiper-main' => array('bwdsypx-ShowcaseProfile_css_path_define'=>BWDSYPX_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/swiper-bundle.min.css'),
			'bwdsypx-ShowcaseProfile-plugin-main' => array('bwdsypx-ShowcaseProfile_css_path_define'=>BWDSYPX_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/main.css'),
        );
        foreach($all_css_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdsypx-ShowcaseProfile_css_path_define'], null, '1.3', 'all');
        }

	}

	//admin-icon
	public function bwdsypx_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdsypx-ShowcaseProfile-admin-main' => array('bwdsypx_path_admin_define'=>BWDSYPX_ASFSK_ASSETS_ADMIN_DIR_FILE . '/css/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdsypx_path_admin_define'], null, '1.3', 'all');
        }
	}

	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdsypx_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdsypx_all_assets_for_elementor_editor_admin']);

		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdsypx_ShowcaseProfile_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdsypx_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdsypx_admin_editor_scripts' ] );

		add_action('add_eael_progressbar_block', [$this, 'add_box_progress_bar_block'], 10, 3);

		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdsypx_ShowcaseProfile::instance();